<?php

class ArtikelController extends Controller
{
	/**
	 * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
	 * using two-column layout. See 'protected/views/layouts/column2.php'.
	 */
	public $layout='//layouts/column2';

	/**
	 * @return array action filters
	 */
	public function filters()
	{
		return array(
			'accessControl', // perform access control for CRUD operations
			'postOnly + delete', // we only allow deletion via POST request
		);
	}

	/**
	 * Specifies the access control rules.
	 * This method is used by the 'accessControl' filter.
	 * @return array access control rules
	 */
	public function accessRules()
	{
		return array(
			array('allow',  // allow all users to perform 'index' and 'view' actions
				'actions'=>array('index','view'),
				'users'=>array('*'),
			),
			/*array('allow', // allow authenticated user to perform 'create' and 'update' actions
				'actions'=>array('create','update'),
				'users'=>array('@'),
			),
			array('allow', // allow admin user to perform 'admin' and 'delete' actions
				'actions'=>array('admin','delete'),
				'users'=>array('admin'),
			),*/
            array('allow', // allow authenticated user to perform 'create' and 'update' actions
                'actions'=>array('create','update'),
                'users'=>array('*'),
            ),
            array('allow', // allow admin user to perform 'admin' and 'delete' actions
                'actions'=>array('admin'),
                'users'=>array('*'),
            ),
			array('deny',  // deny all users
				'actions'=>array('delete'),
                'users'=>array('*'),
			),
		);
	}

	/**
	 * Displays a particular model.
	 * @param integer $id the ID of the model to be displayed
	 */
	public function actionView($id)
	{
		$this->redirect(array('admin'));  
        //$this->render('view',array('model'=>$this->loadModel($id),));
	}

	/**
	 * Creates a new model.
	 * If creation is successful, the browser will be redirected to the 'view' page.
	 */
	public function actionCreate()
	{
		$model=new Artikel;

		// Uncomment the following line if AJAX validation is needed
		$this->performAjaxValidation($model);

		if(isset($_POST['Artikel']))
		{
			//wenn artikelnummer 13stellig -> dann annahme es ist ein barcode und artikelnummer extrahieren
            if(isset($_POST['Artikel']['ArtikelNr']))
            {
                $_POST['Artikel']['ArtikelNr']=Verkauf::convertBarcodeToArtikelnr($_POST['Artikel']['ArtikelNr']);
            }
            
            //preiseingabe wenn in komma dann mit punkt manipulieren, damit eingabe mit komma und punkt möglich
            if(isset($_POST['Artikel']['Preis']))
                $_POST['Artikel']['Preis']=str_replace(",",".",$_POST['Artikel']['Preis']);
            
            $model->attributes=$_POST['Artikel'];
            
            //setze erfrassungszeitstempel
            $model->ErfassungTS=date("Y-m-d H:i:s");
            
			if($model->save())
            {
                //$this->redirect(array('view','id'=>$model->ID));
				
                //wenn eine Kundennummer übergeben wurde dann leite wieder auf diese um
                if(isset($_GET["KundenNr"]) && $_GET["KundenNr"]!="")
                {
                    //entferne alles ausser zahlken aus der nummer und versuche kundenmodell zu loaden
                    $_GET["KundenNr"] = preg_replace('![^0-9]!', '', $_GET["KundenNr"]);
                    $this->redirect(array('create','KundenNr'=>$_GET["KundenNr"])); 
                }
                else
                {
                    $this->redirect(array('create'));
                }
            }
		}

		$this->render('create',array(
			'model'=>$model,
		));
	}

	/**
	 * Updates a particular model.
	 * If update is successful, the browser will be redirected to the 'view' page.
	 * @param integer $id the ID of the model to be updated
	 */
	public function actionUpdate($id)
	{
		$model=$this->loadModel($id);

		// Uncomment the following line if AJAX validation is needed
		// $this->performAjaxValidation($model);

		if(isset($_POST['Artikel']))
		{
			
            $the_image = CUploadedFile::getInstance($model,'Image');
            if (is_object($the_image) && get_class($the_image)==='CUploadedFile')
                $model->Image = $the_image;

            $model->attributes=$_POST['Artikel'];
			if($model->save())
            {
                if(is_object($the_image))
                {
                    $model->Image->saveAs(Yii::getPathOfAlias('webroot').'/images/upload/' . $model->Image);
                }
                
                //$this->redirect(array('view','id'=>$model->ArtikelNr));
                $this->redirect(array('admin'));    
            }
				
		}

		$this->render('update',array(
			'model'=>$model,
		));
	}

	/**
	 * Deletes a particular model.
	 * If deletion is successful, the browser will be redirected to the 'admin' page.
	 * @param integer $id the ID of the model to be deleted
	 */
	public function actionDelete($id)
	{
		$this->loadModel($id)->delete();

		// if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
		if(!isset($_GET['ajax']))
			$this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
	}
    
    /**
    * Löscht das Image aus DB und File von der jeweiligen ArtikelNr
    * @param mixed $id  - ArtikelNr
    */
    public function actionDeleteimage($id)
    {
        $model=$this->loadModel($id);
        
        if($model->Image!=null && file_exists(Yii::getPathOfAlias('webroot').'/images/upload/' . $model->Image))
        {
            unlink(Yii::getPathOfAlias('webroot').'/images/upload/' . $model->Image);       
        }
        $model->Image=null;
        $model->save();
        
        //wird nur aus update aufgerufen, deshalb gehe nach update zurück
        $this->redirect(array('update','id'=>$id)); 
    }

	/**
	 * Lists all models.
	 */
	public function actionIndex()
	{
		/*$dataProvider=new CActiveDataProvider('Artikel');
		$this->render('index',array(
			'dataProvider'=>$dataProvider,
		));*/
        
        /*$model=new Artikel('search');
        $model->unsetAttributes();  // clear any default values
        if(isset($_GET['Artikel']))
            $model->attributes=$_GET['Artikel'];

        $this->render('admin',array(
            'model'=>$model,
        ));*/
        $this->redirect(array('admin'));
	}
    
    /**
     * Druckt eine Liste aller nicht verkauften Artikel
     */
    public function actionPrint()
    {
        $model=new Artikel('search');
        
        //suchparameter eingeben, alles mit Verkauft nein
        $model->unsetAttributes();  // clear any default values
        $model->VerkauftFlag="Nein";
        
        $this->render('print',array(
            'model'=>$model,
        ));
    }

	/**
	 * Manages all models.
	 */
	public function actionAdmin()
	{
		$model=new Artikel('search');
		$model->unsetAttributes();  // clear any default values
		if(isset($_GET['Artikel']))
			$model->attributes=$_GET['Artikel'];

		$this->render('admin',array(
			'model'=>$model,
		));
	}

	/**
	 * Returns the data model based on the primary key given in the GET variable.
	 * If the data model is not found, an HTTP exception will be raised.
	 * @param integer $id the ID of the model to be loaded
	 * @return Artikel the loaded model
	 * @throws CHttpException
	 */
	public function loadModel($id)
	{
		$model=Artikel::model()->findByPk($id);
		if($model===null)
			throw new CHttpException(404,'The requested page does not exist.');
		return $model;
	}

	/**
	 * Performs the AJAX validation.
	 * @param Artikel $model the model to be validated
	 */
	protected function performAjaxValidation($model)
	{
		if(isset($_POST['ajax']) && $_POST['ajax']==='artikel-form')
		{
			echo CActiveForm::validate($model);
			Yii::app()->end();
		}
	}
    
    //beispiel von http://www.yiiframework.com/wiki/278/cgridview-render-customized-complex-datacolumns/
    //assume you have generated the Address model with gii too
    protected function getKundenName($data,$row)
    {     
        $model = Kunden::model()->findByPk($data->RefKundenNr);
     
        //get the view from the address CRUD controller (generated with gii)
        //return $this->renderPartial('../kunden/view',array('model'=>$model),true); //set $return = true, don't display direct
        if(isset($model->Name) && isset($model->KundenNr))
            return (string)$model->Name." (".$model->KundenNr.")";
        else
            return "unbekannt, error?";
    }
    
    //beispiel von http://www.yiiframework.com/wiki/278/cgridview-render-customized-complex-datacolumns/
    //assume you have generated the Address model with gii too
    /**
    * Liefert Formatierten Preis für Ausdruck
    * 
    * @param mixed $data
    * @param mixed $row
    * @return mixed
    */
    protected function getFormatedPreis($data,$row)
    {     
        if(isset($data->Preis) && $data->Preis!="")
            return number_format ( $data->Preis , 2 , "," , "" )." €";
        else
            return "unbekannt, error?";
    }
}
