<?php

class KundenController extends Controller
{
	/**
	 * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
	 * using two-column layout. See 'protected/views/layouts/column2.php'.
	 */
	public $layout='//layouts/column2';

	/**
	 * @return array action filters
	 */
	public function filters()
	{
		return array(
			'accessControl', // perform access control for CRUD operations
			'postOnly + delete', // we only allow deletion via POST request
		);
	}

	/**
	 * Specifies the access control rules.
	 * This method is used by the 'accessControl' filter.
	 * @return array access control rules
	 */
	public function accessRules()
	{
		return array(
			array('allow',  // allow all users to perform 'index' and 'view' actions
				'actions'=>array('index','view'),
				'users'=>array('*'),
			),
			/*array('allow', // allow authenticated user to perform 'create' and 'update' actions
				'actions'=>array('create','update'),
				'users'=>array('@'),
			),
			array('allow', // allow admin user to perform 'admin' and 'delete' actions
				'actions'=>array('admin','delete'),
				'users'=>array('admin'),
			),*/
            array('allow', // allow authenticated user to perform 'create' and 'update' actions
                'actions'=>array('create','update'),
                'users'=>array('*'),
            ),
            array('allow', // allow admin user to perform 'admin' and 'delete' actions
                'actions'=>array('admin'),
                'users'=>array('*'),
            ),
			array('deny',  // deny all users
				'actions'=>array('delete'),
                'users'=>array('*'),
			),
		);
	}

	/**
	 * Displays a particular model.
	 * @param integer $id the ID of the model to be displayed
	 */
	public function actionView($id)
	{
		
        //umleiten auf artikel creat maske mit übergabe der kunden_id
        $this->redirect(array('artikel/create','KundenNr'=>$id));
        
        /*
        //zuerst artikel speichern
        $model_artikel=new Artikel;
        
        // Uncomment the following line if AJAX validation is needed
        //$this->performAjaxValidation($model_artikel);

        if(isset($_POST['Artikel']))
        {
            //preiseingabe wenn in komma dann mit punkt manipulieren, damit eingabe mit komma und punkt möglich
            if(isset($_POST['Artikel']['Preis']))
                $_POST['Artikel']['Preis']=str_replace(",",".",$_POST['Artikel']['Preis']);
            
            $model_artikel->attributes=$_POST['Artikel'];
            if($model_artikel->save())
            {
                $this->redirect(array('view','id'=>$model->KundenNr));
            }
        }

        //artikel view renbdern
        $this->render('view',array('model'=>$model_artikel));
        $this->render('../artikel/_form',array('model'=>$model_artikel));
        
        //$this->renderPartial('../artikel/create', array('model'=>$model_artikel)); 
        
        
        //dann standard kunden view rendern
        $this->render('view',array('model'=>$this->loadModel($id)));
        */
	}

    

	/**
	 * Creates a new model.
	 * If creation is successful, the browser will be redirected to the 'view' page.
	 */
	public function actionCreate()
	{
		$model=new Kunden;

		// Uncomment the following line if AJAX validation is needed
		// $this->performAjaxValidation($model);

		if(isset($_POST['Kunden']))
		{
			$model->attributes=$_POST['Kunden'];
			if($model->save())
            {
                //$this->redirect(array('view','id'=>$model->ID));
                $this->redirect(array('create'));    
            }
				
		}

		$this->render('create',array(
			'model'=>$model,
		));
	}

	/**
	 * Updates a particular model.
	 * If update is successful, the browser will be redirected to the 'view' page.
	 * @param integer $id the ID of the model to be updated
	 */
	public function actionUpdate($id)
	{
		$model=$this->loadModel($id);

		// Uncomment the following line if AJAX validation is needed
		// $this->performAjaxValidation($model);

		if(isset($_POST['Kunden']))
		{
			$model->attributes=$_POST['Kunden'];
			if($model->save())
            {
                //$this->redirect(array('view','id'=>$model->KundenNr));
				$this->redirect(array('admin'));
            }
		}

		$this->render('update',array(
			'model'=>$model,
		));
	}
    
    /**
    * Druckt die Annahmeliste für einen Kunden
    * 
    * @param mixed $id
    */
    public function actionPrint($id)
    {
        $model=$this->loadModel($id);
        
        $this->render('print',array(
            'model'=>$model,
        ));
    }
    
    /**
    * Druckt die Kundenabrechnung (Prozess nur neinmal möglich, dananch wird abgerechnet bFlag von Kunden gesetzt)
    * 
    * @param mixed $id
    */
    public function actionPrintsum($id)
    {
        $model=$this->loadModel($id);
        
        $this->render('printsum',array(
            'model'=>$model,
        ));
        
        //eigenschaften auf Kunde nach rendern ändern damit aufruf nur einmalig möglich
        $model->AbgerechnetTS=date("Y-m-d H:i:s");
        $model->AbgerechnetFlag="Ja";
        $model->save();
    }

	/**
	 * Deletes a particular model.
	 * If deletion is successful, the browser will be redirected to the 'admin' page.
	 * @param integer $id the ID of the model to be deleted
	 */
	public function actionDelete($id)
	{
		$this->loadModel($id)->delete();

		// if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
		if(!isset($_GET['ajax']))
			$this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
	}

	/**
	 * Lists all models.
	 */
	public function actionIndex()
	{
		/*$dataProvider=new CActiveDataProvider('Kunden');
		$this->render('index',array(
			'dataProvider'=>$dataProvider,
		)); */
        $this->redirect(array('admin'));
	}

	/**
	 * Manages all models.
	 */
	public function actionAdmin()
	{
		$model=new Kunden('search');
		$model->unsetAttributes();  // clear any default values
		if(isset($_GET['Kunden']))
			$model->attributes=$_GET['Kunden'];

		$this->render('admin',array(
			'model'=>$model,
		));
	}

	/**
	 * Returns the data model based on the primary key given in the GET variable.
	 * If the data model is not found, an HTTP exception will be raised.
	 * @param integer $id the ID of the model to be loaded
	 * @return Kunden the loaded model
	 * @throws CHttpException
	 */
	public function loadModel($id)
	{
		$model=Kunden::model()->findByPk($id);
		if($model===null)
			throw new CHttpException(404,'The requested page does not exist.');
		return $model;
	}

	/**
	 * Performs the AJAX validation.
	 * @param Kunden $model the model to be validated
	 */
	protected function performAjaxValidation($model)
	{
		if(isset($_POST['ajax']) && $_POST['ajax']==='kunden-form')
		{
			echo CActiveForm::validate($model);
			Yii::app()->end();
		}
	}
    
    //beispiel von http://www.yiiframework.com/wiki/278/cgridview-render-customized-complex-datacolumns/
    //assume you have generated the Address model with gii too
    /**
    * Liefert Formatierten Preis für Ausdruck
    * 
    * @param mixed $data
    * @param mixed $row
    * @return mixed
    */
    protected function getFormatedPreis($data,$row)
    {     
        if(isset($data->Preis) && $data->Preis!="")
            return number_format ( $data->Preis , 2 , "," , "" )." €";
        else
            return "unbekannt, error?";
    }
    
    
    
}
