<?php

class ParameterController extends Controller
{
	/**
	 * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
	 * using two-column layout. See 'protected/views/layouts/column2.php'.
	 */
	public $layout='//layouts/column2';

	/**
	 * @return array action filters
	 */
	public function filters()
	{
		return array(
			'accessControl', // perform access control for CRUD operations
			'postOnly + delete', // we only allow deletion via POST request
		);
	}

	/**
	 * Specifies the access control rules.
	 * This method is used by the 'accessControl' filter.
	 * @return array access control rules
	 */
	public function accessRules()
	{
		return array(
			array('allow',  // allow all users to perform 'index' and 'view' actions
				'actions'=>array('index','view','admin','update'),
				'users'=>array('*'),
			),
			array('allow', // allow admin user to perform 'admin' and 'delete' actions
				'actions'=>array('create','delete','initdb'),
				'users'=>array('admin'),
			),
			array('deny',  // deny all users
				'users'=>array('*'),
			),
		);
	}

	/**
	 * Displays a particular model.
	 * @param integer $id the ID of the model to be displayed
	 */
	public function actionView($id)
	{
		$this->redirect(array('admin'));
        
       /* $this->render('view',array(
			'model'=>$this->loadModel($id),
		));*/
	}

	/**
	 * Creates a new model.
	 * If creation is successful, the browser will be redirected to the 'view' page.
	 */
	public function actionCreate()
	{
		$model=new Parameter;

		// Uncomment the following line if AJAX validation is needed
		// $this->performAjaxValidation($model);

		if(isset($_POST['Parameter']))
		{
			$model->attributes=$_POST['Parameter'];
			if($model->save())
				$this->redirect(array('view','id'=>$model->Name));
		}

		$this->render('create',array(
			'model'=>$model,
		));
	}

	/**
	 * Updates a particular model.
	 * If update is successful, the browser will be redirected to the 'view' page.
	 * @param integer $id the ID of the model to be updated
	 */
	public function actionUpdate($id)
	{
		$model=$this->loadModel($id);

		// Uncomment the following line if AJAX validation is needed
		// $this->performAjaxValidation($model);

		if(isset($_POST['Parameter']))
		{
			$model->attributes=$_POST['Parameter'];
			if($model->save())
				$this->redirect(array('admin'));
		}

		$this->render('update',array(
			'model'=>$model,
		));
	}

	/**
	 * Deletes a particular model.
	 * If deletion is successful, the browser will be redirected to the 'admin' page.
	 * @param integer $id the ID of the model to be deleted
	 */
	public function actionDelete($id)
	{
		$this->loadModel($id)->delete();

		// if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
		if(!isset($_GET['ajax']))
			$this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
	}
    
    /**
    * Initialisiere Datenbank
    */
    public function actionInitdb()
    {
        //löschvorgang durchführen und zurück zu parameterliste
        if(isset($_GET["delete"]) && $_GET["delete"]==1)
        {
            //tabelle artikel neu initialisieren
            Yii::app()->db->createCommand("DROP TABLE IF EXISTS artikel")->query();
            $sql="CREATE TABLE IF NOT EXISTS `artikel` (
          `ArtikelNr` bigint(20) NOT NULL,
          `Name` varchar(100) NOT NULL,
          `Preis` float NOT NULL,
          `Kommentar` varchar(300) DEFAULT NULL,
          `RefKundenNr` bigint(20) NOT NULL,
          `VerkauftFlag` varchar(5) NOT NULL DEFAULT 'Nein',
          `VerkauftTS` datetime DEFAULT NULL,
          `ErfassungTS` datetime DEFAULT NULL,
          `Image` varchar(100) DEFAULT NULL,
          PRIMARY KEY (`ArtikelNr`),
          KEY `RefKundenNr` (`RefKundenNr`),
          KEY `VerkauftFlag` (`VerkauftFlag`),
          KEY `ErfassungsTS` (`ErfassungTS`)
        ) ENGINE=InnoDB DEFAULT CHARSET=latin1;";
        Yii::app()->db->createCommand($sql)->query();
        
        //tabelle kunden neu initialisieren
            Yii::app()->db->createCommand("DROP TABLE IF EXISTS kunden")->query();
            $sql="CREATE TABLE IF NOT EXISTS `kunden` (
          `KundenNr` bigint(20) NOT NULL AUTO_INCREMENT,
          `Name` varchar(100) NOT NULL,
          `Telefon` varchar(100) NOT NULL,
          `Kommentar` varchar(300) DEFAULT NULL,
          `AbgerechnetFlag` varchar(5) NOT NULL DEFAULT 'Nein',
          `AbgerechnetTS` datetime DEFAULT NULL,
          `VerwaltungBezahltFlag` varchar(5) NOT NULL DEFAULT 'Ja',
          PRIMARY KEY (`KundenNr`)
        ) ENGINE=InnoDB  DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;";
        Yii::app()->db->createCommand($sql)->query();
            
            //tabelle verkauf neu initialisieren
            Yii::app()->db->createCommand("DROP TABLE IF EXISTS verkauf")->query();
            $sql="CREATE TABLE IF NOT EXISTS `verkauf` (
          `ID` bigint(20) NOT NULL AUTO_INCREMENT,
          `SessionID` varchar(100) NOT NULL,
          `ErfassterBarcode` varchar(50) NOT NULL,
          `RefArtikelNr` bigint(20) DEFAULT NULL,
          `ErfassungTS` datetime NOT NULL,
          `VerkaufErledigt` varchar(5) NOT NULL DEFAULT 'Nein',
          PRIMARY KEY (`ID`),
          KEY `SessionID` (`SessionID`),
          KEY `ErfassungTS` (`ErfassungTS`),
          KEY `VerkaufErledigt` (`VerkaufErledigt`)
        ) ENGINE=InnoDB DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;";
        Yii::app()->db->createCommand($sql)->query();
        
        //tabelle reklamation neu initialisieren
            Yii::app()->db->createCommand("DROP TABLE IF EXISTS reklamation")->query();
            $sql="CREATE TABLE IF NOT EXISTS `reklamation` (
          `ReklamationNr` bigint(20) NOT NULL AUTO_INCREMENT,
          `RefKundenNr` bigint(20) NOT NULL,
          `RefArtikelNr` bigint(20) NOT NULL,
          `Beschwerde` varchar(3000) NOT NULL,
          `AngedachteLoesung` varchar(3000) DEFAULT NULL,
          `Status` varchar(50) DEFAULT NULL,
          `ErfassungTS` datetime DEFAULT NULL,
          PRIMARY KEY (`ReklamationNr`)
        ) ENGINE=InnoDB  DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;";
        Yii::app()->db->createCommand($sql)->query();
        
        //tabelle parameter neu initialisieren
            Yii::app()->db->createCommand("DROP TABLE IF EXISTS parameter")->query();
            $sql="CREATE TABLE IF NOT EXISTS `parameter` (
          `Name` varchar(50) NOT NULL,
          `Wert` text NOT NULL,
          `Laenge` int(11) DEFAULT NULL,
          `Typ` varchar(10) DEFAULT NULL,
          `Beschreibung` varchar(300) NOT NULL,
          PRIMARY KEY (`Name`)
        ) ENGINE=InnoDB DEFAULT CHARSET=latin1;";
        Yii::app()->db->createCommand($sql)->query();
        $sql="INSERT INTO `parameter` (`Name`, `Wert`, `Laenge`, `Typ`, `Beschreibung`) VALUES
        ('abrechnung_betrag_verwaltungsaufwand', '0.5', 5, 'float_0-10', 'Wieviel Euro sollen als Verwaltungsaufwand pro Position berechnet werden (Eingabe 0.01=1cent bis 10=10€)'),
        ('abrechnung_disclaimer', 'Mit dieser Unterschrift wird die Abrechnung gültig und kann bei der Kassa eingelöst werden.', 2000, 'text', 'Dieser Text wird in der Kundenabrechnung zwischen der Überschrift Freigabe und dem Unterschriftsfeld dargestellt'),
        ('abrechnung_provision_prozent', '15', 2, 'zahl_1-99', 'Wieviel Prozent sollen in der Abrechnung als Provision einbehalten werden'),
        ('annahmeliste_disclaimer', 'Der Veranstalter übernimmt keine Gewährleistung für die Richtigkeit der Angebotsangaben, die Qualität, Funktions- sowie Gebrauchsfähigkeit der Angebotsgegenstände.\r\nDie TMK-Koppl übt nur eine Vermittlertätigkeit aus. Es kann keine Haftung für Diebstahl, Verlust, Beschädigung oder Größenangaben übernommen werden. <br><br>Umtausch oder Reklamation ist nicht möglich. Es werden 15% des Verkaufserlöses, sowie 50 Cent für jeden abgegebenen Artikel eingehoben.', 2000, 'text', 'Dieser Text wird in der Annahmeliste zwischen der Überschrift Disclaimer und dem Unterschriftsfeld dargestellt'),
        ('etikett_header', 'Tauschmarkt der TMK-Koppl 2013', 30, 'text', 'Text der in der ersten Zeile am Etikett angezeigt wird'),
        ('etikett_von', '1', 5, 'ganzzahl', 'Hier wird festgelegt ab welcher Artikelnummer die weiteren Etiketten gedruckt werden sollen, Default=1. Dadurch soll erinnert/verhindert werden, dass Etiketten mehrfach gedruckt werden.'),
        ('unterschrift_ort', 'Koppl', 50, 'text', 'Der Folgende Text wird als Ort neben dem Datum bei der Unterschrift angegeben');";
        Yii::app()->db->createCommand($sql)->query();
            
            //hochgeladene bilder und der thumbnail cache löschen nund verzeichnisse wieder erstellen
            $this->deletedir_recursive(Yii::getPathOfAlias('webroot').'/images/upload/');
            mkdir(Yii::getPathOfAlias('webroot').'/images/upload/');
            $this->deletedir_recursive(Yii::getPathOfAlias('webroot').'/cache/easyimage/');
            mkdir(Yii::getPathOfAlias('webroot').'/cache/easyimage/');
            
            //assets cache löschen
            $this->deletedir_recursive(Yii::getPathOfAlias('webroot').'/assets/');
            mkdir(Yii::getPathOfAlias('webroot').'/assets/');
            
            $this->redirect(array('admin')); 
        }
        else
        {
            //anzeige von löschdialog ja/nein
            $this->render('initdb');      
        } 
    }

	/**
	 * Lists all models.
	 */
	public function actionIndex()
	{
		$this->redirect(array('admin'));
        
        /*$dataProvider=new CActiveDataProvider('Parameter');
		$this->render('index',array(
			'dataProvider'=>$dataProvider,
		));*/
	}

	/**
	 * Manages all models.
	 */
	public function actionAdmin()
	{
		$model=new Parameter('search');
		$model->unsetAttributes();  // clear any default values
		if(isset($_GET['Parameter']))
			$model->attributes=$_GET['Parameter'];

		$this->render('admin',array(
			'model'=>$model,
		));
	}

	/**
	 * Returns the data model based on the primary key given in the GET variable.
	 * If the data model is not found, an HTTP exception will be raised.
	 * @param integer $id the ID of the model to be loaded
	 * @return Parameter the loaded model
	 * @throws CHttpException
	 */
	public function loadModel($id)
	{
		$model=Parameter::model()->findByPk($id);
		if($model===null)
			throw new CHttpException(404,'The requested page does not exist.');
		return $model;
	}

	/**
	 * Performs the AJAX validation.
	 * @param Parameter $model the model to be validated
	 */
	protected function performAjaxValidation($model)
	{
		if(isset($_POST['ajax']) && $_POST['ajax']==='parameter-form')
		{
			echo CActiveForm::validate($model);
			Yii::app()->end();
		}
	}
    
    /**
    * Löscht rekursiv ein Verzeichniss
    * @param mixed $dir
    */
    private function deletedir_recursive($dir)
    {
        //input von hier http://www.ulrich-block.de/rekursives-loschen-oder-rm-r-mit-php/
        // Wenn der Input ein Ordner ist, dann Überprüfung des Inhaltes beginnen
        if (is_dir($dir)) {
            // Ordnerinhalt auflisten und jedes Element nacheinander überprüfen
            $dircontent=scandir($dir);
            foreach ($dircontent as $c) {
                // Wenn es sich um einen Ordner handelt, die Funktion rmr(); aufrufen
                if ($c!='.' and $c!='..' and is_dir($dir.DIRECTORY_SEPARATOR.$c)) {
                    $this->deletedir_recursive($dir.DIRECTORY_SEPARATOR.$c);
                // Wenn es eine Datei ist, diese löschen
                } else if ($c!='.' and $c!='..') {
                    if(file_exists($dir.DIRECTORY_SEPARATOR.$c))
                        unlink($dir.DIRECTORY_SEPARATOR.$c);
                }
            }
            // Den nun leeren Ordner löschen
            if(file_exists($dir))
                rmdir($dir);
        // Wenn es sich um eine Datei handelt, diese löschen
        } else {
            if(file_exists($dir))
                unlink($dir);
        }
    }

}
