<?php

/**
 * This is the model class for table "artikel".
 *
 * The followings are the available columns in table 'artikel':
 * @property string $ArtikelNr
 * @property string $Name
 * @property double $Preis
 * @property string $Kommentar
 * @property string $RefKundenNr
 * @property string $VerkauftFlag
 * @property string $VerkauftTS
 * @property string $ErfassungTS
 * @property string $Image
 */
class Artikel extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'artikel';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
            array('ArtikelNr, Name, Preis, RefKundenNr', 'required'),
            array('ArtikelNr','unique', 'message'=>'Die Artikelnummer muss ohne führende Nullen eingegeben werden und darf nur einmal verwendet werden'), //stellt sicher dass die artikelnummer nicht nur in der db sondern auch im model all unique behandelt wird
            //array('Preis', 'numerical'),
            //array('Preis', 'numerical', 'integerOnly'=>FALSE,'numberPattern'=>'/^\s*[-+]?[0-9]*\,?[0-9]+([eE][-+]?[0-9]+)?\s*$/','message'=>'Preiseingabe ungültig'),
            //array('Preis', 'numerical', 'integerOnly'=>FALSE,'numberPattern'=>'/[1-9](?:\d{0,2})(?:,\d{3})*(?:\.\d*[1-9])?|0?\.\d*[1-9]|0/','message'=>'Preiseingabe ungültig v2'),
            //array('Preis', 'numerical', 'integerOnly'=>FALSE,'numberPattern'=>'/^(([1-9]*)|(([1-9]*).([0-9]*)))$/','message'=>'Preiseingabe ungültig v2'),
            array('Preis', 'validatePreis','message'=>'Preiseingabe ungültig, Format 12345,12 verwenden, Max=99999 Min=0,01'),
            
            //upload image
            array('Image', 'file','types'=>'jpg', 'allowEmpty'=>true, 'on'=>'update', 'maxSize'=>5097152, 'tooLarge'=>'Das Bild darf maximal 5MB haben'), // this will allow empty field when page is update (remember here i create scenario update)
            
            array('ArtikelNr, RefKundenNr', 'length', 'max'=>20),
            array('Name, Image', 'length', 'max'=>100),
            array('Kommentar', 'length', 'max'=>300),
            array('VerkauftFlag', 'length', 'max'=>5),
            // The following rule is used by search().
            // todo Please remove those attributes that should not be searched.
            array('ArtikelNr, Name, Preis, Kommentar, RefKundenNr, VerkauftFlag, VerkauftTS, ErfassungTS, Image', 'safe', 'on'=>'search'),
        );
        
        /*
        return array(
            array('Bezeichnung, Preis, RefKundenID', 'required'),
			array('Bezeichnung', 'length', 'max'=>255),
            //array('Preis', 'numerical'),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('ID, Bezeichnung,Preis, RefKundenID', 'safe', 'on'=>'search'),
            
            //sicherstellen, dass nur nummerische werte eingegeben werden dürfen
            //array('Preis', 'match', 'numberPattern'=>'/^[\w\s,]+$/', 'message'=>'Tags can only contain word characters.'),
            //array('Preis', 'numerical', 'numberPattern'=>'/^\d+\.?\d*$/','message'=>'Preis muss als Zahl mit Beistrich eingegeben werden'),
            array('Preis','numerical',
                'integerOnly'=>false,
                'min'=>'0.01',
                'max'=>'99999',
                'tooSmall'=>'Preis beträgt mindestens 0,01€',
                'tooBig'=>'Preis beträgt maximal 99999€',
                'message'=>'Der Preis muss als Zahl mit Punkt angegeben werden'),  
                
		);*/
	}
    
    /**
    * Eigene Validierungsroutine um Preise zu validieren gültig Format 12345,12 oder 12345.11 verwenden, Max=99999 Min=0,01
    * 
    * @param mixed $attribute
    * @param mixed $params
    */
    public function validatePreis($attribute,$params)
    {
        //info von http://stackoverflow.com/questions/15516172/how-to-add-rules-using-yii-framework-in-model
        
        $error=null;
        $attribute_content=$this[$attribute];
        
        //ersetze komma durch punkt für validierung
        $attribute_content=str_replace(",",".",$attribute_content);
        
        //daten eine zahl
        if(!is_numeric($attribute_content))
            $error=1;
            
        //zahlk zwischen 0,01 und 99999
        if((float)$attribute_content < 0.01 || $attribute_content>99999)
            $error=1;
        
        //maximal 5 corkomma und 2 nachkommastellen    
        $split=explode(".",$attribute_content);
        if((isset($split[0]) && strlen($split[0])>5) || (isset($split[1]) && strlen($split[1])>2))
            $error=1;    
            
        if($error)
        {
            //$this->addError('duration','validation message');
            $this->addError($attribute,$params['message']);
        }
    }



	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
        //Infos von http://www.yiiframework.com/doc/guide/1.1/en/database.arr#disambiguating-column-names
		return array(
            'RefKundenID'=>array(self::HAS_ONE, 'Kunden', 'ID')
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
    public function attributeLabels()
    {
        return array(
            'ArtikelNr' => 'Artikel Nr',
            'Name' => 'Name',
            'Preis' => 'Preis',
            'Kommentar' => 'Kommentar',
            'RefKundenNr' => 'KundenNr',
            'VerkauftFlag' => 'Verkauft',
            'VerkauftTS' => 'Verkauft am/um',
            'ErfassungTS' => 'Erfasst am/um',
            'Image' => 'Artikelbild'
        );
    }

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('ArtikelNr',$this->ArtikelNr,true);
        $criteria->compare('Name',$this->Name,true);
        $criteria->compare('Preis',$this->Preis);
        $criteria->compare('Kommentar',$this->Kommentar,true);
        $criteria->compare('RefKundenNr',$this->RefKundenNr,false); //wird nur exakt zurück geben
        $criteria->compare('VerkauftFlag',$this->VerkauftFlag,true);
        $criteria->compare('VerkauftTS',$this->VerkauftTS,true);
        $criteria->compare('ErfassungTS',$this->ErfassungTS,true);
        $criteria->compare('Image',$this->Image,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
            'pagination'=>array('pageSize'=>50,), //50 artikel pro seite
            'sort'=>array(
                'defaultOrder'=>'ErfassungTS DESC')
		));
        
        
        
	}
    
    /**
    * Liste aller Artikel auf einer seite sortiert nach KundenNr, Einschränkung nur auf VerkaufFlag
    */
    public function searchForPrintListeNichtVerkauft()
    {
        // todo Please modify the following code to remove attributes that should not be searched.

        $criteria=new CDbCriteria;
        $criteria->compare('VerkauftFlag',$this->VerkauftFlag,false); //teilweise übereinstimmung nein = 3. parameter auf false

        return new CActiveDataProvider($this, array(
            'criteria'=>$criteria,
            'pagination'=>array('pageSize'=>999999,), //99999 artikel pro seite
            'sort'=>array(
                'defaultOrder'=>'RefKundenNr ASC')
        ));
        
    }
    
    /**
    * Liste von 100Artikeln pro seite Sortiert nach Artikelnr, Einschränkung nur auf Kunde
    * 
    */
    public function searchForPrint()
    {
        // todo Please modify the following code to remove attributes that should not be searched.

        $criteria=new CDbCriteria;
        $criteria->compare('RefKundenNr',$this->RefKundenNr,false); //teilweise übereinstimmung nein = 3. parameter auf false

        return new CActiveDataProvider($this, array(
            'criteria'=>$criteria,
            'pagination'=>array('pageSize'=>1000,), //1000 artikel pro seite
            'sort'=>array(
                'defaultOrder'=>'ArtikelNr ASC')
        ));
        
    }
    
    /**
    * Berechnet die benötigten Werte für die Endabrechnung
    * 
    * @param mixed $KundenNr
    * @param mixed $add_verwaltungsaufwand wenn auf true wird verwaltungsaufwand mit berechnet, sonnst nicht
    * @return mixed
    */
    public function calcKunde($KundenNr,$add_verwaltungsaufwand)
    {
        //wieviel prozent der verkauften artikel werden als provision berechnet, aktuell 15
        //$calc_provision=15; 
        $calc_provision=(int)Parameter::model()->findByPk("abrechnung_provision_prozent")->Wert; 
        //wieviel verwaltungsaufwand in € wird pro Artikel berechnet
        //$calc_verwaltungsaufwand=0.5;
        $calc_verwaltungsaufwand=(float)Parameter::model()->findByPk("abrechnung_betrag_verwaltungsaufwand")->Wert; 
        
        //initialisieren des returns
        $return_array["sum"]["raw"]=0;
        $return_array["sum"]["readable"]="0,00 €";
        $return_array["sum"]["text"]="Summe Verkauf";
        $return_array["provision"]["raw"]=0; 
        $return_array["provision"]["readable"]="0,00 €";
        $return_array["provision"]["text"]="einbehaltene Provision";
        $return_array["anzahl"]["raw"]=0;
        $return_array["anzahl"]["readable"]="0";
        $return_array["anzahl"]["Text"]="Anzahl der Artikel";
        $return_array["verwaltung"]["raw"]=0;
        $return_array["verwaltung"]["readable"]="0,00 €";
        $return_array["verwaltung"]["text"]="Verwaltungsaufwand";
        $return_array["total"]["raw"]=0;
        $return_array["total"]["readable"]="0,00 €";
        $return_array["total"]["text"]="Gesamt Summe";
        
        //daten aus db abfragen
        $sql_anzahl=0;
        $sql_anzahl = (int)Yii::app()->db->createCommand("SELECT count(*) as Anzahl  FROM artikel where RefKundenNr=".$KundenNr."")->queryScalar();
        
        $sql_summe=0;
        $sql_summe = (float)Yii::app()->db->createCommand("SELECT sum(preis) as Summe FROM artikel where RefKundenNr=".$KundenNr." and VerkauftFlag='Ja'")->queryScalar();
        
        //werte berechnen
        if($sql_anzahl!=0 && $add_verwaltungsaufwand==true)
        {
            $return_array["anzahl"]["raw"]=$sql_anzahl;
            $return_array["anzahl"]["readable"]="".$sql_anzahl."";
            $return_array["verwaltung"]["raw"]=($sql_anzahl*$calc_verwaltungsaufwand);
            $return_array["verwaltung"]["readable"]=number_format ( ($sql_anzahl*$calc_verwaltungsaufwand) , 2 , "," , "" )." €";   
        }
        //werte berechnen
        if($sql_summe!=0)
        {
            $return_array["sum"]["raw"]=$sql_summe;
            $return_array["sum"]["readable"]=number_format ( $sql_summe , 2 , "," , "" )." €";  
            $return_array["provision"]["raw"]=(float)(($sql_summe/100)*$calc_provision);
            $return_array["provision"]["readable"]=number_format ( ((($sql_summe/100)*$calc_provision)) , 2 , "," , "" )." €";   
        }
        
        //gesamtsumme berechnen
        if($sql_summe!=0 || $sql_anzahl!=0)
        {
            $return_array["total"]["raw"]=$return_array["sum"]["raw"]-$return_array["provision"]["raw"]-$return_array["verwaltung"]["raw"];
            $return_array["total"]["readable"]=number_format ( $return_array["total"]["raw"] , 2 , "," , "" )." €";     
        }
        
        return $return_array;
    }
    
    
    

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Artikel the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
