<?php

/**
 * This is the model class for table "kunden".
 *
 * The followings are the available columns in table 'kunden':
 * @property string $KundenNr
 * @property string $Name
 * @property string $Telefon
 * @property string $Kommentar
 * @property string $AbgerechnetFlag
 * @property string $AbgerechnetTS
 * @property string $VerwaltungBezahltFlag
 */
class Kunden extends CActiveRecord
{
    /**
     * @return string the associated database table name
     */
    public function tableName()
    {
        return 'kunden';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules()
    {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('Name, Telefon', 'required'),
            array('Name, Telefon', 'length', 'max'=>100),
            array('Kommentar', 'length', 'max'=>300),
            array('AbgerechnetFlag, VerwaltungBezahltFlag', 'length', 'max'=>5),
            array('AbgerechnetTS', 'safe'),
            // The following rule is used by search().
            // todo Please remove those attributes that should not be searched.
            array('KundenNr, Name, Telefon, Kommentar, AbgerechnetFlag, AbgerechnetTS', 'safe', 'on'=>'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations()
    {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels()
    {
        return array(
            'KundenNr' => 'Kunden Nr',
            'Name' => 'Name',
            'Telefon' => 'Telefon',
            'Kommentar' => 'Kommentar',
            'AbgerechnetFlag' => 'Abgerechnet',
            'AbgerechnetTS' => 'Abgerechnet am/um',
            'VerwaltungBezahltFlag' => 'Verwaltungsabgabe bezahlt',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search()
    {
        // todo Please modify the following code to remove attributes that should not be searched.

        $criteria=new CDbCriteria;

        $criteria->compare('KundenNr',$this->KundenNr,true);
        $criteria->compare('Name',$this->Name,true);
        $criteria->compare('Telefon',$this->Telefon,true);
        $criteria->compare('Kommentar',$this->Kommentar,true);
        $criteria->compare('AbgerechnetFlag',$this->AbgerechnetFlag,true);
        $criteria->compare('AbgerechnetTS',$this->AbgerechnetTS,true);
        $criteria->compare('VerwaltungBezahltFlag',$this->VerwaltungBezahltFlag,true);

        return new CActiveDataProvider($this, array(
            'criteria'=>$criteria,
            'pagination'=>array('pageSize'=>50,), //50 kunden pro seite
            'sort'=>array(
                'defaultOrder'=>'KundenNr DESC')
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return Kunden the static model class
     */
    public static function model($className=__CLASS__)
    {
        return parent::model($className);
    }
}

?>
